Name: liquibase
Summary: Database Refactoring Tool
Version: 3.5.3
Release: 3%{?dist}
License: ASL 2.0
URL: http://www.liquibase.org

Source0: https://github.com/liquibase/liquibase/archive/%{name}-parent-%{version}.tar.gz

# See https://liquibase.jira.com/browse/CORE-2933
Patch0: liquibase-javacc.patch

BuildRequires: felix-framework
BuildRequires: felix-osgi-core
BuildRequires: java-devel >= 0:1.6.0
BuildRequires: javapackages-tools
BuildRequires: maven-local
BuildRequires: mvn(commons-cli:commons-cli)
BuildRequires: mvn(javax.enterprise:cdi-api)
BuildRequires: mvn(javax.servlet:servlet-api)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.ant:ant)
BuildRequires: mvn(org.apache.derby:derby)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.maven:maven-compat)
BuildRequires: mvn(org.apache.maven:maven-plugin-api)
BuildRequires: mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires: mvn(org.apache.maven.shared:maven-plugin-testing-harness)
BuildRequires: mvn(org.apache.velocity:velocity)
BuildRequires: mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires: mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires: mvn(org.hsqldb:hsqldb)
BuildRequires: mvn(org.hsqldb:hsqldb)
BuildRequires: mvn(org.jboss.weld.se:weld-se)
BuildRequires: mvn(org.osgi:org.osgi.core)
BuildRequires: mvn(org.springframework:spring-beans)
BuildRequires: mvn(org.springframework:spring-context)
BuildRequires: mvn(org.springframework:spring-core)
BuildRequires: mvn(org.yaml:snakeyaml)

BuildArch:     noarch

Requires: java-headless >= 0:1.6.0
Requires: javapackages-tools
Requires: mvn(org.yaml:snakeyaml) >= 0:1.13

%description
LiquiBase is an open source (Apache 2.0 License), database-independent library
for tracking, managing and applying database changes. It is built on a simple
premise: All database changes are stored in a human readable but tracked in
source control.


%package javadoc
Summary: API documentation for %{name}
%description javadoc
This package contains %{summary}.


%package cdi
Summary: Liquibase CDI
%description cdi
Liquibase CDI extension.


%package parent
Summary: Liquibase Parent Configuration POM
%description parent
This package contains the %{summary}.


%package maven-plugin
Summary: Maven plugin for %{name}
BuildRequires: mvn(org.apache.maven:maven-project)
BuildRequires: mvn(org.apache.maven:maven-core)
Requires: %{name} = %{version}-%{release}
Requires: maven

%description maven-plugin
%{summary}.

%prep
%setup -q -n %{name}-%{name}-parent-%{version}
%patch0 -p1

find -name "*.bat" -print -delete
find -name "*.class" -print -delete
find -name "*.jar" -print -delete
# Do not bundle javascript libraries and fonts
find -name "*.js" -print -delete
rm -r %{name}-core/src/main/resources/liquibase/sdk/watch/{css,fonts}
rm -r %{name}-core/src/main/resources/assembly
rm -r %{name}-core/src/main/resources/dist

%pom_disable_module %{name}-integration-tests
%pom_disable_module %{name}-debian
%pom_disable_module %{name}-rpm

# Use Maven 3 APIs only
%pom_change_dep -r :maven-project :maven-compat
# Add missing test dep
%pom_add_dep junit:junit:4.12:test %{name}-maven-plugin

# Unavailable plugin
%pom_remove_plugin -r :gmaven-plugin
# Unwanted tasks
%pom_remove_plugin -r :maven-assembly-plugin
%pom_remove_plugin -r :maven-deploy-plugin
%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-source-plugin

%pom_change_dep -r org.springframework:spring :spring-core
%pom_add_dep org.springframework:spring-beans %{name}-core
%pom_add_dep org.springframework:spring-context %{name}-core
%pom_add_dep org.apache.felix:org.apache.felix.framework %{name}-core

# Remove all test dependencies.  We aren't running tests with this build.
%pom_xpath_remove "pom:dependency[pom:scope = 'test' ]" %{name}-core
rm -r %{name}-core/src/test/*
# Disable test jar
%pom_xpath_remove "pom:plugin[pom:artifactId = 'maven-jar-plugin' ]/pom:executions" %{name}-core

# Drop pre-existent manifest file and prevent OutOfMemoryError
rm %{name}-core/src/main/resources/META-INF/MANIFEST.MF

%pom_xpath_remove "pom:finalName" %{name}-core
%pom_add_plugin org.apache.felix:maven-bundle-plugin:2.5.4 %{name}-core '
<extensions>true</extensions>
<configuration>
  <instructions>
    <Liquibase-Package>liquibase.change,liquibase.changelog,liquibase.database,liquibase.parser,liquibase.precondition,liquibase.datatype,liquibase.serializer,liquibase.sqlgenerator,liquibase.executor,liquibase.snapshot,liquibase.logging,liquibase.diff,liquibase.structure,liquibase.structurecompare,liquibase.lockservice,liquibase.sdk.database,liquibase.ext</Liquibase-Package>
    <Main-Class>liquibase.integration.commandline.Main</Main-Class>
  </instructions>
</configuration>
<executions>
  <execution>
    <id>bundle-manifest</id>
    <phase>process-classes</phase>
    <goals>
      <goal>manifest</goal>
    </goals>
  </execution>
</executions>'
%pom_xpath_set pom:manifestFile '${project.build.outputDirectory}/META-INF/MANIFEST.MF' %{name}-core

# Symlink liquibase/liquibase-core.jar to liquibase.jar
%mvn_file :%{name}-core %{name}/%{name}-core %{name}


%build
%mvn_build -s -f


%install
%mvn_install
%jpackage_script liquibase.integration.commandline.Main "" "" %{name}/%{name}-core %{name} true
%__mkdir_p %{buildroot}%{_mandir}/man1
install -pm 0644 %{name}-rpm/src/main/resources/%{name}.1 %{buildroot}%{_mandir}/man1/


%files -f .mfiles-%{name}-core
%defattr(-,root,root)
%doc changelog.txt %{name}-core/DEV_NOTES.txt
%license LICENSE.txt
%doc %{_mandir}/man1/%{name}.1*
%{_bindir}/%{name}

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%files parent -f .mfiles-%{name}-parent
%license LICENSE.txt

%files cdi -f .mfiles-%{name}-cdi
%license LICENSE.txt

%files maven-plugin -f .mfiles-%{name}-maven-plugin

%changelog
* Wed Nov 22 2017 Alex Wood <awood@redhat.com> 3.5.3-3
- Apply patch to address https://liquibase.jira.com/browse/CORE-2933

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Oct 14 2016 Alex Wood <awood@redhat.com> 3.5.3-1
- Update to 3.5.3

* Fri May 13 2016 Alex Wood <awood@redhat.com> 3.5.1-1
- Update to 3.5.1
- Bring package build into compliance with Java packaging guidelines

* Fri Apr 22 2016 Alex Wood <awood@redhat.com> 3.5.0-1
- Update to 3.5.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Sep 15 2015 Alex Wood <awood@redhat.com> 3.4.1-1
- Update to 3.4.1

* Tue Jul 07 2015 Alex Wood <awood@redhat.com> 3.4.0-1
- Update to 3.4.0

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Nov 04 2014 Alex Wood <awood@redhat.com> 3.3.0-1
- Update to 3.3.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 27 2014 Alex Wood <awood@redhat.com> 3.1.1-1
- Update to 3.1.1
- Switch to Maven based build

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 3.1.0-2
- Use Requires: java-headless rebuild (#1067528)

* Mon Jan 13 2014 Alex Wood <awood@redhat.com> 3.1.0-1
- Update to 3.1.0

* Mon Oct 28 2013 Alex Wood <awood@redhat.com> - 3.0.7-4
- Update to 3.0.7.
- Use jpackage-utils to generate launch script.
- Split javadoc into separate package.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Apr 17 2013 Alex Wood <awood@redhat.com> 2.0.5-2
- Build now requires servlet3 instead of servlet25.

* Wed Apr 03 2013 Alex Wood <awood@redhat.com> 2.0.5-1
- Updating to liquibase 2.0.5.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 03 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-7
- 818510: Fix offline failures looking for dbchangelog XSD.
  (dgoodwin@redhat.com)

* Mon Apr 16 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-6
- Generate and package javadocs.
- Cleanup rpmlint warnings.
- Switched to using javadir macro.
- Switched to using build-classpath in launcher.
* Tue Apr 03 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-5
- Spec cleanup. (dgoodwin@redhat.com)

* Mon Apr 02 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-4
- Fix missing javax.servlet during compile. (dgoodwin@redhat.com)

* Fri Mar 30 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-3
- Include documentation, better tar.gz generation. (dgoodwin@redhat.com)
- Add custom launcher script. (dgoodwin@redhat.com)
- Add build.xml to compile. (dgoodwin@redhat.com)

* Thu Mar 29 2012 Devan Goodwin <dgoodwin@redhat.com> 2.0.3-2
- Initial packaging attempt.


